%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code runs the TVP-VAR presented in the paper: 
% "Expectation-Driven Cycles and the Changing Dynamics of Unemployment"
% A. D'Agostino, C. Mendicino and F. Puglisi
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear
close all
clc

addpath('../codes')

[A B] = xlsread('data 16052018',1);

[date, daten] = makedate(1968,12,2017,9,'Q');

X = A(:,3:22);
%1. UNEX EX Q3 
%2. UNEX EX Q4 
%3. UNEX EX Q5 
%4. UNEX EX Q6 
%5. CPI EX Q3 
%6. CPI EX Q4 
%7. CPI EX Q5 
%8. CPI EX Q6
%9. UR  3 month average
%10. INFL (CPI) 3 month average
%11. INFL (CPI core) 3 month average
%12. TBILL 3 month average	
%13. TBILL average 10 more
%14. UR  last month
%15. INFL (CPI) last month
%16. INFL (CPI core) last month
%17. TBILL last month
%18. S&P500 3 month average
%19. S&P500 3 month average, real
%20. S&P500 average 10 more

%XX = [X(:,1) X(:,5) X(:,6) X(:,8)  ];
XX = [X(:,1) X(:,9) X(:,10) X(:,12)  ];
XX=XX(1:end,:);
[B_ols, T_stat, Fore, irf, irfs, c_cov] = var_est_f(XX , 4, 1 , 1,24);
figure(1)
subplot(2,2,1); plot((1:24+1)',-squeeze(irfs(1,1,:)),'LineWidth',3); grid on ; axis([1 24+1 -inf inf])
title('RESPONSE OF EXPECTED UR TO EXPECTED UR SHOCK', 'FontSize', 16)
subplot(2,2,2); plot((1:24+1)',-squeeze(irfs(2,1,:)),'LineWidth',3); grid on ; axis([1 24+1 -inf inf])
title('RESPONSE OF UR TO EXPECTED UR SHOCK', 'FontSize', 16)
subplot(2,2,3); plot((1:24+1)',-squeeze(irfs(3,1,:)),'LineWidth',3); grid on ; axis([1 24+1 -inf inf])
title('RESPONSE OF INFLATION TO EXPECTED UR SHOCK', 'FontSize', 16)
subplot(2,2,4); plot((1:24+1)',-squeeze(irfs(4,1,:)),'LineWidth',3); grid on ; axis([1 24+1 -inf inf])
title('RESPONSE OF INTEREST RATE TO EXPECTED UR SHOCK', 'FontSize', 16)
set(gcf,'Color',[1,1,1])
set(gca,'FontSize',12)

gbit = 1;
maxgbit     =  12000;        % total number of draws
burn        =  10000;         % burn in period
jump            =    5;           % collect one each jump draws
horizon = 12;
p = 2;
% total credit 0.1 -- IR 0.04 or 0.03 -- HP 0.1 -- SP 0.1 
% HP & IR 0.1 -- TC and IR 0.1
tight_Q = 0.0005;
tight_W = 0.0005;
tight_S = 0.0005;

post_index = 1;
trs=0;
trsMax=100;
MaxEig=1.0;
MaxRoot=MaxEig+1;
c=1;
L=p;
MixingKSC;

[PRED_tv_var, PB,outR, outy2star,outB,outA,PR] = TvVarEstKSC(XX,tight_Q,tight_W,tight_S,gbit,maxgbit,burn,jump,post_index,trs,trsMax,MaxEig,MaxRoot,c,L,horizon,ksc);

% Uncomment to plot three dimensional IRFs
% N =size(XX,2);
% for t=1:size(PB,2)
%     t
%     for g=1:size(PB,3)
%         IRF1(:,:,:,t,g) =irf_chol(PB(:,t,g),PR(:,:,t,g),size(XX,2),p,c,16,1);
%     end
% end
% temp=median(IRF1,5);


save Estimated_Results.mat
