%% %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code replicates the Tables and Figures of the paper: 
% "Expectation-Driven Cycles and the Changing Dynamics of Unemployment"
% A. D'Agostino, C. Mendicino and F. Puglisi
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Set-up Folders
clc
clear
addpath('codes')
addpath('Data_Code_Estimates')

%% Figures with Data only

[A B] = xlsread('data 16052018',1);

name = 'MS14-543R1';
X = A(:,3:22);
%1. UNEX EX Q3 
%2. UNEX EX Q4 
%3. UNEX EX Q5 
%4. UNEX EX Q6 
%5. CPI EX Q3 
%6. CPI EX Q4 
%7. CPI EX Q5 
%8. CPI EX Q6
%9. UR  3 month average
%10. INFL (CPI) 3 month average
%11. INFL (CPI core) 3 month average
%12. TBILL 3 month average	
%13. TBILL average 10 more
%14. UR  last month
%15. INFL (CPI) last month
%16. INFL (CPI core) last month
%17. TBILL last month
%18. S&P500 3 month average
%19. S&P500 3 month average, real
%20. S&P500 average 10 more

XX = [X(:,1) X(:,9) X(:,10) X(:,12)  ];
for i= 1:size(XX,1)
    for j = 1:size(XX,2)
        if XX(i,j)== -999 
            XX(i,j)= (XX(i-1,j)+XX(i+1,j))/2;
            if XX(i,j)<-100 
                XX(i,j)=XX(i-1,j);
            end
        end
        if XX(i,j)<-100 
            XX(i,j)=XX(i-1,j);
        end
    end
end

XX_f = [X(:,1) X(:,2) X(:,3) X(:,4) X(:,9)  ];

for i= 1:size(XX_f,1)
    for j = 1:size(XX_f,2)
        if XX_f(i,j)== -999 
            XX_f(i,j)= NaN;
        end
        
    end
end

[date, daten] = makedate(1968,12,2017,09,'Q');
% Create datevector for graphs

start_date_g = datenum('Q3-1965','QQ-YYYY');
end_date_g   = datenum('Q4-2017','QQ-YYYY');
n_dates= 6;

datevec_g= [start_date_g daten([round(1:196/n_dates:196)])' end_date_g];
datelab_g= datestr(datevec_g,'QQ-YYYY');
title_font_size_g= 14;

%% Figures For Data Section 

% Figure Data 1
figure(1111)

plot(daten,XX_f(:,1),'b-.','LineWidth',1); hold on
plot(daten,XX_f(:,2),'b--','LineWidth',1);
plot(daten,XX_f(:,3),'b-*','LineWidth',1);
plot(daten,XX_f(:,4),'b*-','LineWidth',1);
plot(daten,XX_f(:,5),'r-.','LineWidth',3);
hold off
set(gca,'FontSize',10,'XTick',datevec_g, 'XTickLabel', datelab_g);
legend('1 quarter ahead', '2 quarter ahead','3 quarter ahead','4 quarter ahead', 'Relized')
%title('EX-UR and realized UR', 'FontSize', title_font_size_g)

set(gcf,'Color',[1,1,1])
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);
saveas (figure(1111), [name 'FigD1'])
eval(['print ', '-depsc  ', '  ', [name 'FigD1'] ]);

figure(1)

subplot(2,2,1); plot(daten,XX(:,1),'LineWidth',1); 
set(gca,'FontSize',10,'XTick',datevec_g, 'XTickLabel', datelab_g); 
title('EX-UR', 'FontSize', title_font_size_g)

subplot(2,2,2);plot(daten,XX(:,2),'LineWidth',1); %datetick('x','QQ-YYYY') 
set(gca,'FontSize',10,'XTick',datevec_g, 'XTickLabel', datelab_g);
title('UR', 'FontSize', title_font_size_g)

subplot(2,2,3);plot(daten,XX(:,3),'LineWidth',1); %datetick('x','QQ-YYYY') 
set(gca,'FontSize',10,'XTick',datevec_g, 'XTickLabel', datelab_g); 
title('CPI', 'FontSize', title_font_size_g)

subplot(2,2,4);plot(daten,XX(:,4),'LineWidth',1); %datetick('x','QQ-YYYY') 
set(gca,'FontSize',10,'XTick',datevec_g, 'XTickLabel', datelab_g); 
title('R', 'FontSize', title_font_size_g)

set(gcf,'Color',[1,1,1])
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);
saveas (figure(1), [name 'FigD2'])
eval(['print ', '-depsc  ', '  ', [name 'FigD2'] ]);

%% Figure 1

close all

% Find Dates for Plot

Crisis_dates = [1980 3;
              1980 9
              1981 9
              1982 12
              1990 9
              1991 3
              2001 3 
              2001 12
              2007 12
              2009 6];
idx_end_dates_crisis = zeros(size(Crisis_dates,1)/2,1);
tmp_count=2;
for i= 1:size(Crisis_dates,1)/2
    
    index_tmp1=find(date(:,1)==Crisis_dates(tmp_count,1)& date(:,2)==Crisis_dates(tmp_count,2) ,100);
    idx_end_dates_crisis(i)=index_tmp1;
    
   tmp_count=tmp_count+2; 
end
figure(33)
%24-3,24+11, 33, 66, 109, 139, 154
%nvector = [24,33,66,109,139,154];
X_axisA3= [-5, -4, -3, -2, -1, 0, 1 : 10];
hax=axes; 
x=0:0.1:10; 
hold on
first_crisis= NaN(size(X_axisA3));
first_crisis(1:size(XX(idx_end_dates_crisis(1)-5:idx_end_dates_crisis(1)+3,2),1))= XX(idx_end_dates_crisis(1)-5:idx_end_dates_crisis(1)+3,2);
plot(X_axisA3,first_crisis,'bs-.','LineWidth',1);
plot(X_axisA3,XX(idx_end_dates_crisis(2)-5:idx_end_dates_crisis(2)+10,2),'b*-','LineWidth',1);
plot(X_axisA3,XX(idx_end_dates_crisis(3)-5:idx_end_dates_crisis(3)+10,2),'bo--','LineWidth',2);
plot(X_axisA3,XX(idx_end_dates_crisis(4)-5:idx_end_dates_crisis(4)+10,2),'b--','LineWidth',2);
plot(X_axisA3,XX(idx_end_dates_crisis(5)-5:idx_end_dates_crisis(5)+10,2),'b-','LineWidth',3);
%plot(X_axisA3,XX(154-3:154+11,2),'b--',X_axisA3,XX(154-3:154+11,2),'b^','LineWidth',1);
SP=0; %your point goes here 
line([SP SP],get(hax,'YLim'),'Color',[1 0 0])
hold off
legend({'1980:I-1980:III', '1981:III-1982:IV', '1990:III-1991:1', '2001:I-2001:IV', '2007:IV-2009:II'}, 'Location','southwest');
%legend('Orientation','horizontal', 'location', 'southeast')
set(legend,...
    'Position',[0.14597656015285 0.0160095579450419 0.747708186473074 0.0439068108903892],...
    'Orientation','horizontal',...
    'FontSize',16);
%title('Unemployement', 'FontSize', title_font_size_g)
set(gca,'XTick',X_axisA3);
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);
saveas (figure(33), [name 'Fig1'])
eval(['print ', '-depsc  ', '  ', [name 'Fig1'] ]);

%% Table I Watson

% NBER Recession Dates 1980Q1-1980Q3, 1981Q3-1982Q4, 1990Q3-1991Q1,
% 2001Q1-2001Q4, 2007Q4-2009Q2
%legend({'1980:I-1980:III', '1981:III-1982:IV', '1990:III-1991:I', '2001:I-2001:IV', '2007:IV-2009:II'}, 'Location','southwest');

%Watson Table 
for j=1:4
    clear table_Watson
    clear reces_dates recess_end_dates
    if j<3
    reces_dates = [1979 3%6;
                   1979 12;
                   1989 9%12; 
                   1990 6;
                   2000 3%6; 
                   2000 12;
                   2006 12; %2007 3
                   2007 9]; %9
    recess_end_dates = [ 1982 12;
                         1991 3;
                         2001 12;
                         2009 6];
    else
    reces_dates = [1979 3%6;
                   1979 12;
                   1980 9%12;
                   1981 6;
                   1989 9%12; %12
                   1990 6;
                   2000 3%6; %2000 %12
                   2000 12;
                   2006 12; %2007 3
                   2007 9]; %9  
               
    recess_end_dates = [ 1980 9;
                         1982 12;
                         1991 3;
                         2001 12;
                         2009 6];
           
    end    
               
tmp_count=1;
tmp_c=1;
q_peak_stable=0;
q_end_stable= 12; %24
q_before_stable = 0; %3
for i = 1: size(reces_dates,1)/2
    q_before = q_before_stable;
    q_end= q_end_stable;
    q_peak= q_peak_stable;
    if j==1 || j==3
        q_ahead=24;
        
    elseif j==2 %variable date double dip crisis together 
        if i<2
        q_ahead=24;
        elseif i==2
            q_ahead=20;
            
        elseif i==3
            q_ahead=20;
            q_peak =0;%14;
        else
            q_ahead=32;
        end
        
    elseif j==4
        if i==1
            q_ahead=5;
            q_peak = 0;%4;
            q_end  = 3;
        elseif i==2
            q_ahead=16;
            q_peak= q_peak_stable;
            q_end= q_end_stable;
            q_before = 0;
        elseif i==3
            q_ahead=20;
            q_peak= q_peak_stable;
            q_end= q_end_stable;
        elseif i==4
            q_ahead=20;
            q_peak= 0;%13;
            if q_end>19 
                q_end= 19; 
            end
        else
            q_ahead=32;
            q_peak= q_peak_stable;
            q_end= q_end_stable;
        end
    end 

    index_tmp1=find(date(:,1)==reces_dates(tmp_count,1)& date(:,2)==reces_dates(tmp_count,2) ,100);
    index_tmp2=find(date(:,1)==reces_dates(tmp_count+1,1)& date(:,2)==reces_dates(tmp_count+1,2) ,100);
    index_tmp3=find(date(:,1)==recess_end_dates(i,1)& date(:,2)==recess_end_dates(i,2) ,100);

    table_Watson{tmp_c,1}   = strcat(['Avg. Inflation '  datestr(daten(index_tmp1),'YYYY:QQ'), '-',  datestr(daten(index_tmp2),'YYYY:QQ')]);
    table_Watson{tmp_c+1,1} = strcat(['Avg. Inflation '  datestr(daten(index_tmp1+q_ahead),'YYYY:QQ'), '-',  datestr(daten(index_tmp2+q_ahead),'YYYY:QQ')]);
    table_Watson{tmp_c+2,1} = strcat(['Change in Inflation']); 
    table_Watson{tmp_c+3,1} = strcat(['Avg. Unemployement '  datestr(daten(index_tmp1),'YYYY:QQ'), '-',  datestr(daten(index_tmp2),'YYYY:QQ')]);
    [a_tmp b_tmp]           = max(XX(index_tmp2+1:index_tmp2+q_ahead,2));
    b_tmp= b_tmp+index_tmp2;
    table_Watson{tmp_c+4,1} = strcat(['Peak Unemployement '  datestr(daten(b_tmp),'YYYY:QQ')]);
    table_Watson{tmp_c+5,1} = strcat(['Avg. Unemployement '  datestr(daten(index_tmp1+q_ahead),'YYYY:QQ'), '-',  datestr(daten(index_tmp2+q_ahead),'YYYY:QQ')]);
    table_Watson{tmp_c+6,1} = strcat(['Change Unemployement '  datestr(daten(index_tmp1),'YYYY:QQ'), '- Peak']);
    table_Watson{tmp_c+7,1} = strcat(['Change Unemployement '  datestr(daten(index_tmp1),'YYYY:QQ'), '-',  datestr(daten(index_tmp2+q_ahead),'YYYY:QQ')]);
    table_Watson{tmp_c+8,1} = strcat(['Correlation Unemp-Infl overall period ' datestr(daten(index_tmp1-q_before),'YYYY:QQ') ' ' datestr(daten(index_tmp2+q_ahead),'YYYY:QQ') ]);
    table_Watson{tmp_c+9,1} = strcat(['Correlation Unemp-Infl up to peak '  datestr(daten(index_tmp1-q_before),'YYYY:QQ') ' ' datestr(daten(b_tmp),'YYYY:QQ') ]);
    table_Watson{tmp_c+10,1}= strcat(['Correlation Unemp-Infl up 5 years from peak '  datestr(daten(index_tmp1-q_before),'YYYY:QQ') ' ' datestr(daten(b_tmp+q_peak),'YYYY:QQ') ]);
    table_Watson{tmp_c+11,1}= strcat(['Correlation Unemp-Infl up 6 years from recession end '  datestr(daten(index_tmp1-q_before),'YYYY:QQ') ' ' datestr(daten(index_tmp3+q_end),'YYYY:QQ') ]);

    %    [a_tmp b_tmp]= max(XX(index_tmp2+1:index_tmp2+q_ahead,2));
    

    table_Watson{tmp_c,2}   = (mean(XX(index_tmp1:index_tmp2,3)));
    table_Watson{tmp_c+1,2} = (mean(XX(index_tmp1+q_ahead:index_tmp2+q_ahead,3)));
    table_Watson{tmp_c+2,2} = ((table_Watson{tmp_c,2})- (table_Watson{tmp_c+1,2}));
    table_Watson{tmp_c+3,2} = (mean(XX(index_tmp1:index_tmp2,2)));
    table_Watson{tmp_c+4,2} = (max(XX(index_tmp2+1:index_tmp2+q_ahead,2)));
    table_Watson{tmp_c+5,2} = (mean(XX(index_tmp1+q_ahead:index_tmp2+q_ahead,2)));
    table_Watson{tmp_c+6,2} = (table_Watson{tmp_c+4,2}- table_Watson{tmp_c+3,2});    
    table_Watson{tmp_c+7,2} = (table_Watson{tmp_c+5,2}- table_Watson{tmp_c+3,2});
    table_Watson{tmp_c+8,2} = corr(XX(index_tmp1-q_before:index_tmp2+q_ahead,3),XX(index_tmp1-q_before:index_tmp2+q_ahead,2));
    table_Watson{tmp_c+9,2} = corr(XX(index_tmp1-q_before:b_tmp,3),             XX(index_tmp1-q_before:b_tmp,2));
    table_Watson{tmp_c+10,2}= corr(XX(index_tmp1-q_before:b_tmp+q_peak,3),      XX(index_tmp1-q_before:b_tmp+q_peak,2));
    table_Watson{tmp_c+11,2}= corr(XX(index_tmp1-q_before:index_tmp3+q_end,3),  XX(index_tmp1-q_before:index_tmp3+q_end,2));
    
    tmp_count= tmp_count+2;
    tmp_c =tmp_c+12;
end

xlswrite([name 'Tbl1.xlsx'],table_Watson, j, 'A1')
end
%% Figures from Estimation Results
clear
clc
close all 

name1 = 'MS14-543R1';

% load('Estimated_Results_big.mat')
% clearvars -except PB PR p c MaxEig N XX 
% save Estimated_Results

loadname= strcat('Estimated_Results');

load(loadname);

%% Dates For Figures
[date, daten] = makedate(1968,12,2017,09,'Q');
temp_date = date(end-size(PB,2)+1:end,:);
[date1, daten1] = makedate(temp_date(1,1),temp_date(1,2),temp_date(end,1),temp_date(end,2),'Q');
start_date_g1 = datenum(['Q1-' num2str(temp_date(1,1))],'QQ-YYYY');
end_date_g1   = datenum(['Q3-'  num2str(temp_date(end,1))],'QQ-YYYY');
n_dates= 6;

datevec_g1= [start_date_g1 daten1([round(1:size(daten1,1)/n_dates:size(daten1,1))])' end_date_g1];
datelab_g1= datestr(datevec_g1,'QQ-YYYY');
title_font_size_g1= 24;

% New Dataset starting from 1981, new estimates from 1991.
%% Store Coefficent and Stochastic Volatility Matrices
PB_Median = median(PB,3);
PB_25Q = prctile(PB,25,3);
PB_75Q = prctile(PB,75,3);
PB_Mean = mean(PB,3);


% Stochastic Volatility 

PR_Median = median(PR,4);
PR_25Q = prctile(PR,25,4);
PR_75Q = prctile(PR,75,4);
PR_Mean = mean(PR,4);


%% OLS Results UR Shock
close all
[B_ols, T_stat, Fore, irf_ols, irfs,c_cov, RES, maxEig] = var_est_f(XX(1:end,:) , 4, 1 , 1,24);

% OLS Historical Decomposition

HDOLS= VARhd_Fede(reshape(B_ols,17,4),4,4,size(XX,1),XX(1:end,:),RES, 1, c_cov);
%% Historical Decomposition
XX=XX;
HD= VARhd_Fede_time_varying(PB,4,2,XX(end-size(PB,2)+1:end,:), 1, PR);

%% Figure 7
close all
names={'EX-UR','UR','CPI','R'};
ivar=2;
Crisis_dates = [1980 3;
              1980 9
              1981 9
              1982 12
              1990 9
              1991 3
              2001 3 
              2001 12
              2007 12
              2009 6];
idx_end_dates_crisis = zeros(size(Crisis_dates,1)/2,1);
tmp_count=2;
%index_strt_all=find(date1(:,1)==2000 & date1(:,2)==3 ,100);
index_strt_all=find(date1(:,1)==1978 & date1(:,2)==12 ,100);
      
for i= 1:size(Crisis_dates,1)/2
    
    index_tmp1=find(date1(:,1)==Crisis_dates(tmp_count,1)& date1(:,2)==Crisis_dates(tmp_count,2) ,100);
    idx_end_dates_crisis(i)=index_tmp1;
    index_tmp2=find(date1(:,1)==Crisis_dates(tmp_count-1,1)& date1(:,2)==Crisis_dates(tmp_count-1,2) ,100);
    idx_strt_dates_crisis(i)=index_tmp2;
    
   tmp_count=tmp_count+2; 
end
temp_data_fig7 = XX(end-size(PB,2)+1:end,:);

figure(7771)

xs= index_strt_all:size(PB,2);
step_dates_xs= round(length(xs)/6);
date_xs= index_strt_all:step_dates_xs:size(PB,2);
if date_xs(end)== xs(end)
else
    date_xs= [date_xs xs(end)];
end
plot(xs,temp_data_fig7(xs,ivar),'b-','LineWidth',1); hold on 
plot(xs,HD.endo_noshock(xs,ivar),'r-','LineWidth',1); grid on ;
for irec=1:length(idx_strt_dates_crisis)
    ybars= zeros(1,2);
    ybars(1)=idx_strt_dates_crisis(irec);
    ybars(2)=idx_end_dates_crisis(irec);
patch([ybars(1) ybars(1), ybars(2) ybars(2)],[min(ylim) max(ylim) max(ylim) min(ylim)], [0.8 0.8 0.8])
end
plot(xs,temp_data_fig7(xs,ivar),'b-','LineWidth',1); hold on 
plot(xs,HD.endo_noshock(xs,ivar),'r-','LineWidth',1); grid on ;
set(gca,'XTick',[date_xs]);
set(gca,'XTickLabel',datestr(daten1(date_xs),'YYYY-QQ'));

legend('Realized Series', 'Counterfactual Series')

hold off
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);

saveas (figure(7771), [name1 'Fig7'])
eval(['print ', '-depsc  ', '  ', [name1 'Fig7'] ]);


%% Figure 8

Crisis_dates = [1980 3;
              1980 9
              1981 9
              1982 12
              1990 9
              1991 3
              2001 3 
              2001 12
              2007 12
              2009 6];
idx_end_dates_crisis = zeros(size(Crisis_dates,1)/2,1);
tmp_count=2;

for i= 1:size(Crisis_dates,1)/2
    
    index_tmp1=find(date1(:,1)==Crisis_dates(tmp_count,1)& date1(:,2)==Crisis_dates(tmp_count,2) ,100);
    idx_end_dates_crisis(i)=index_tmp1;
    index_tmp2=find(date1(:,1)==Crisis_dates(tmp_count-1,1)& date1(:,2)==Crisis_dates(tmp_count-1,2) ,100);
    idx_strt_dates_crisis(i)=index_tmp2;
    
   tmp_count=tmp_count+2; 
end
temp_data_fig7 = XX(end-size(PB,2)+1:end,:);
tempqs_deft=5;
tempqe_deft=10;
figure(771)
for i=4:length(idx_end_dates_crisis) %1:length(idx_end_dates_crisis) for the five recession picture 
subplot(2,1,i-3) %subplot(3,2,i) for the five recession picture 
if i==1
    tempqe=3;
    tempqs=3;
elseif i==4
   tempqs=7;
   tempqe=5;
elseif i==5
   tempqs= 25; %7; for the five recession picture 
   tempqe= 33; %tempqe_deft; for the five recessions picture 
else
    tempqe=tempqe_deft;
    tempqs=tempqs_deft;
end
xs= idx_end_dates_crisis(i)-tempqs:idx_end_dates_crisis(i)+tempqe;
step_dates_xs= round(length(xs)/6);
date_xs= idx_end_dates_crisis(i)-tempqs:step_dates_xs:idx_end_dates_crisis(i)+tempqe;
if date_xs(end)== xs(end)
else
    date_xs= [date_xs xs(end)];
end
plot(xs,temp_data_fig7(xs,1),'b-','LineWidth',1); hold on 
plot(xs,HD.endo_noshock(xs,1),'r-','LineWidth',1); grid on ;
for irec=i %1:length(idx_strt_dates_crisis)
    ybars= zeros(1,2);
    ybars(1)=(idx_strt_dates_crisis(irec));
    ybars(2)=(idx_end_dates_crisis(irec));
patch([ybars(1) ybars(1), ybars(2) ybars(2)],[min(ylim) max(ylim) max(ylim) min(ylim)], [0.8 0.8 0.8])
end
plot(xs,temp_data_fig7(xs,1),'b-','LineWidth',1); hold on 
plot(xs,HD.endo_noshock(xs,1),'r-','LineWidth',1); grid on ;
hold off
set(gca,'XTick',[date_xs]);
set(gca,'XTickLabel',datestr(daten1(date_xs),'YYYY-QQ'));
eval(['title(','''', 'RECESSION ' , datestr(daten1(idx_strt_dates_crisis(i)),'YYYY:QQ'), '-'...
    datestr(daten1(idx_strt_dates_crisis(i)),'YYYY:QQ'), '''' ',' '''', 'FontSize','''',',', '14', ')'])
SP=idx_end_dates_crisis(i); %your point goes here 
axis tight
yl = ylim;
%line([SP SP],yl,'Color',[1 0 0])
if i==5
legend('Realized Series', 'Counterfactual Series')
set(legend,...
    'Position',[0.79457465098343 0.113038487740829 0.108463543461015 0.0462129246885493]);

end
hold off
end

set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);
saveas (figure(771), [name1 'Fig8'])
eval(['print ', '-depsc  ', '  ', [name1 'Fig8'] ]);
 

%% OLS VAR Figure with Confidence Bands
[INF,SUP,INF1,SUP1,MED,BAR] = conf_bands_OLS(25,10000,reshape(B_ols,17,4),4,4,size(XX,1),XX,RES, 1);
%% Figure 2
close all

figure(2)
title('OLS Results UR Shock')
%hold on
subplot(2,2,1); plot((1:24+1)',squeeze(irf_ols(1,1,:)),'b-','LineWidth',3); grid on ; axis([1 24+1 -inf inf])
hold on
plot((1:24+1)',squeeze(INF(1,1,:)),'b-.'); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(INF1(1,1,:)),'b--', 'LineWidth',2); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(SUP(1,1,:)),'b-.'); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(SUP1(1,1,:)),'b--','LineWidth',2); grid on ; axis([1 24+1 -inf inf])


%legend('Point Est','5th Perc','Median', '95th perc')
hold off
title('EX-UR', 'FontSize', 16)
subplot(2,2,2); plot((1:24+1)',squeeze(irf_ols(2,1,:)),'b-','LineWidth',3); grid on ; axis([1 24+1 -inf inf])
hold on
plot((1:24+1)',squeeze(INF(2,1,:)),'b-.'); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(INF1(2,1,:)),'b--', 'LineWidth',2); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(SUP(2,1,:)),'b-.'); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(SUP1(2,1,:)),'b--','LineWidth',2); grid on ; axis([1 24+1 -inf inf])

%legend('Point Est','5th Perc','Median', '95th perc')
hold off
title('UR', 'FontSize', 16)
subplot(2,2,3); plot((1:24+1)',squeeze(irf_ols(3,1,:)),'b-','LineWidth',3); grid on ; axis([1 24+1 -inf inf])
hold on
plot((1:24+1)',squeeze(INF(3,1,:)),'b-.'); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(INF1(3,1,:)),'b--', 'LineWidth',2); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(SUP(3,1,:)),'b-.'); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(SUP1(3,1,:)),'b--','LineWidth',2); grid on ; axis([1 24+1 -inf inf])

%legend('Point Est','5th Perc','Median', '95th perc')
hold off
title('CPI', 'FontSize', 16)
subplot(2,2,4); plot((1:24+1)',squeeze(irf_ols(4,1,:)),'b-','LineWidth',3); grid on ; axis([1 24+1 -inf inf])
hold on
plot((1:24+1)',squeeze(INF(4,1,:)),'b-.'); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(INF1(4,1,:)),'b--', 'LineWidth',2); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(SUP(4,1,:)),'b-.'); grid on ; axis([1 24+1 -inf inf])
plot((1:24+1)',squeeze(SUP1(4,1,:)),'b--','LineWidth',2); grid on ; axis([1 24+1 -inf inf])

hold off
title('R', 'FontSize', 16)
set(gcf,'Color',[1,1,1])
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);
saveas (figure(2), [name1 'Fig2'])
eval(['print ', '-depsc  ', '  ', [name1 'Fig2'] ]);

%% Execute Variance Decomposition of TV-VAR
t_max= 101;
IRF1= zeros(N,N,t_max,size(PB,2),size(PB,3));
for t=1:size(PB,2)
    t
    for g=1:size(PB,3)
        [IRF1(:,:,:,t,g), var_dec] =irf_chol(PB(:,t,g),PR(:,:,t,g),size(XX,2),p,c,t_max-1,1);
        VAR_DEC(:,:,t,g)= squeeze(var_dec(1:size(PR,1),1,:));
    end
end
IRF100 = IRF1;
IRF1 = IRF100(:,:,1:16,:,:);
%% Variance Decomposition Table
Table_VD=zeros(6,11);
index_2000=find(date1(:,1)==2000& date1(:,2)==3 ,100);
q_indexes= [2,4,8,20,40,100];
XX_estim= XX(end-size(PB,2)+1:end,:);
Table_VD(:,1)= mean(median(VAR_DEC(2,q_indexes,[1:index_2000-1],:),4),3);
Table_VD(:,2)= mean(median(VAR_DEC(2,q_indexes,[index_2000:end],:),4),3);
Table_VD(:,3)= mean(median(VAR_DEC(2,q_indexes,:,:),4),3);
Table_VD(:,4)= mean(median(VAR_DEC(3,q_indexes,[1:index_2000-1],:),4),3);
Table_VD(:,5)= mean(median(VAR_DEC(3,q_indexes,[index_2000:end],:),4),3);
Table_VD(:,6)= mean(median(VAR_DEC(3,q_indexes,:,:),4),3);
Table_VD(:,7)= mean(median(VAR_DEC(4,q_indexes,[1:index_2000-1],:),4),3);
Table_VD(:,8)= mean(median(VAR_DEC(4,q_indexes,[index_2000:end],:),4),3);
Table_VD(:,9)= mean(median(VAR_DEC(4,q_indexes,:,:),4),3);
Table_VD(:,10)= mean(median(VAR_DEC(1,q_indexes,[1:index_2000-1],:),4),3);
Table_VD(:,11)= mean(median(VAR_DEC(1,q_indexes,[index_2000:end],:),4),3);
Table_VD(:,12)= mean(median(VAR_DEC(1,q_indexes,:,:),4),3);
Table_VD(1,13)= std(XX_estim([1:index_2000-1],1));
Table_VD(1,14)= std(XX_estim([index_2000:end],1));
Table_VD(1,15)= std(XX_estim(:,1));

xlsname=[name1 'Tbl2.xlsx'];
xlswrite(xlsname,Table_VD, 1, 'A1')

%% Figure Recession Variable(i) to Shock(i)
rnames={'EX-UR','UR','CPI','R'};
shocknames={'EX-UR','UR','CPI','R'};
close all

for i1=2
    for i2=1
    
    figure(5900+i1*10+i2)
    plot(prctile(squeeze(mean((IRF1(i1,i2,:,[6:9  ],:)),4)),[30 70],2),':','linewidth',2)
    hold on
    plot(prctile(squeeze(mean((IRF1(i1,i2,:,[12:17],:)),4)),[30 70],2),'+','linewidth',2)
    plot(prctile(squeeze(mean((IRF1(i1,i2,:,[47:50],:)),4)),[30 70],2),'d','linewidth',2)
    plot(prctile(squeeze(mean((IRF1(i1,i2,:,[90:93],:)),4)),[30 70],2),'-.','linewidth',2)
    plot(prctile(squeeze(mean((IRF1(i1,i2,:,[117:123],:)),4)),[30 70],2),'linewidth',2)
    hold off
    axis tight
    yl=ylim;
    yl= [yl(1)-0.2 yl(2)+0.2];
    close
    figure(5000+i1*10+i2)
    subplot(3,2,1)
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[6:9],:),4)),[50 ],2),'linewidth',2)
    hold on
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[6:9],:),4)),[30 70 ],2),'b:','linewidth',2)
    ylim([yl])
    grid on
    title('RECESSION 1980-1981', 'FontSize', 18)
    subplot(3,2,2)
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[12:17],:),4)),[50 ],2),'linewidth',2)
    hold on
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[12:17],:),4)),[30 70 ],2),'b:','linewidth',2)
    ylim([yl])
    grid on
    title('RECESSION 1981-1982', 'FontSize', 18)
    subplot(3,2,3)
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[47:50],:),4)),[50 ],2),'linewidth',2)
    hold on
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[47:50],:),4)),[30 70 ],2),'b:','linewidth',2)
    ylim([yl])
    grid on
    title('RECESSION 1990-1991', 'FontSize', 18)
    subplot(3,2,4)
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[90:93],:),4)),[50 ],2),'linewidth',2)
    hold on
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[90:93],:),4)),[30 70 ],2),'b:','linewidth',2)
    ylim([yl])
    grid on
    title('RECESSION 2001', 'FontSize', 18)
    subplot(3,2,5)
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[117:123],:),4)),[50 ],2),'linewidth',2)
    hold on
    plot(prctile(squeeze(mean(IRF1(i1,i2,:,[117:123],:),4)),[30 70 ],2),'b:','linewidth',2)
    ylim([yl])
    grid on
    title('RECESSION 2007-2009', 'FontSize', 18)
    subplot(3,2,6)
    plot(median(squeeze(mean((IRF1(i1,i2,:,[6 7 8],:)),4)),2),':','linewidth',2)
    hold on
    plot(median(squeeze(mean((IRF1(i1,i2,:,[12:17],:)),4)),2),'+','linewidth',2)
    plot(median(squeeze(mean((IRF1(i1,i2,:,[47:50],:)),4)),2),'d','linewidth',2)
    plot(median(squeeze(mean((IRF1(i1,i2,:,[90:93],:)),4)),2),'-.','linewidth',2)
    plot(median(squeeze(mean((IRF1(i1,i2,:,[117:123],:)),4)),2),'linewidth',2)
    ylim([yl])
    title('AVERAGE IRF DURING THE FIVE RECESSION', 'FontSize', 18)
    grid on
    set(gcf,'Color',[1,1,1])
    legend('recession: 80-81','recession: 81-82','recession: 90-91','recession: 01', 'recession: 07-09','Location','SouthEast')
    legend('location', 'southeast')
    
    set(legend,...
    'Position',[0.28181897091056 0.0538513974096796 0.439732149537622 0.0251789370685024],...
    'Orientation','horizontal');
    box(legend,'off')
    hold off
    set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);
    saveas (figure(5000+i1*10+i2), [name1 'Fig3'])
    eval(['print ', '-depsc  ', '  ', [name1 'Fig3'] ]);
    end
end

%% Figure Recession Variable(i) to EX_UR shock 
shockname= {'EXURShock','URShock','CPIShock','RShock'};
close all
for ii = 1%1:N
figure(40+ii)
clear names
names= {'UR','CPI', 'R'};
for i = 2:N
    
subplot(N-1,1,i-1)
plot(median(squeeze(mean((IRF1(i,ii,:,[6 7 8],:)),4)),2),':','linewidth',2)
hold on
plot(median(squeeze(mean((IRF1(i,ii,:,[12:17],:)),4)),2),'+','linewidth',2)
plot(median(squeeze(mean((IRF1(i,ii,:,[47:50],:)),4)),2),'d','linewidth',2)
plot(median(squeeze(mean((IRF1(i,ii,:,[90:93],:)),4)),2),'-.','linewidth',2)
plot(median(squeeze(mean((IRF1(i,ii,:,[117:123],:)),4)),2),'linewidth',2)
if ii==1
%ylim([-2 1.5])
ylim([-1.5 2])
elseif ii==2
%ylim([-2 4.1])     
ylim([-4.1 2])     
elseif ii==3
%ylim([-1.5 0.5])    
ylim([-0.5 1.5])    
else
%ylim([-3 0.85]) 
ylim([-0.85 3]) 
end
%title('AVERAGE IRF DURING THE FIVE RECESSION', 'FontSize', 18)
grid on
set(gcf,'Color',[1,1,1])
if i==3
legend('recession: 80-81','recession: 81-82','recession: 90-91','recession: 01', 'recession: 07-09','Location','SouthEast')
legend('location', 'southeast')
set(legend,...
    'Position',[0.28181897091056 0.0538513974096796 0.439732149537622 0.0251789370685024],...
    'Orientation','horizontal');
end
eval(['title( ','''' names{i-1} '''', ',' '''fontsize''',',','14',')']);
%box(legend,'off')
end

hold off
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);
saveas (figure(40+ii), [name1 'Fig4'])
eval(['print ', '-depsc  ', '  ', [name1 'Fig4'] ]);

end


%% Figure 5 and 6 : Conditional Moments with Grey Bands
name1 = 'MS14-543R1';
close all
n=size(XX,2);
p=2;
date_strt_all= find(date1(:,1)==1990 & date1(:,2)== 3);

Crisis_dates = [1980 3;
              1980 9
              1981 9
              1982 12
              1990 9
              1991 3
              2001 3 
              2001 12
              2007 12
              2009 6];
idx_end_dates_crisis = zeros(size(Crisis_dates,1)/2,1);
tmp_count=2;

for i= 1:size(Crisis_dates,1)/2
    
    index_tmp1=find(date1(:,1)==Crisis_dates(tmp_count,1)& date1(:,2)==Crisis_dates(tmp_count,2) ,100);
    idx_end_dates_crisis(i)=index_tmp1;
    index_tmp2=find(date1(:,1)==Crisis_dates(tmp_count-1,1)& date1(:,2)==Crisis_dates(tmp_count-1,2) ,100);
    idx_strt_dates_crisis(i)=index_tmp2;
    
   tmp_count=tmp_count+2; 
end
tmp_conditional_shock = {'EX UR', 'UR', 'CPI', 'IR'};
for cc= 1 %:4
    % clears everything as there was some wrong summation over loop
    % iterations

    clc
    clearvars -except name1 n p tmp_conditional_shock cc name loadname ...
        idx_strt_dates_crisis idx_end_dates_crisis date_strt_all
        load(loadname);
        [date, daten] = makedate(1968,12,2017,09,'Q');
        temp_date = date(end-size(PB,2)+1:end,:);
        [date1, daten1] = makedate(temp_date(1,1),temp_date(1,2),temp_date(end,1),temp_date(end,2),'Q');
        start_date_g1 = daten1(1);
        end_date_g1   = daten1(end);
        date_strt_all= find(date1(:,1)==1991 & date1(:,2)== 3);
        n_dates= 6; %6;
%         datevec_g1= [daten1([round(1:size(daten1,1)/n_dates:size(daten1,1))])' end_date_g1];
%         datelab_g1= datestr(datevec_g1,'QQ-YYYY');
        datevec_g1= [daten1([round(date_strt_all:size(daten1,1)/n_dates:size(daten1,1))])' end_date_g1];

        datelab_g1= datestr(datevec_g1,'QQ-YYYY');
        n_dates= 4;
        datevec_g2= [daten1([round(date_strt_all:size(daten1,1)/n_dates:size(daten1,1))])' end_date_g1];
        %datevec_g2= [daten1([round(1:size(daten1,1)/n_dates:size(daten1,1))])' end_date_g1];
        datelab_g2= datestr(datevec_g2,'QQ-YYYY');

        tmp_name = strcat([tmp_conditional_shock{cc}]);
                
        cc
        
for t=1: size(PB,2)
    t
    for g=1:size(PB,3)
        C = companion(PB(:,t,g),p,n,1);
        CH = ([chol(PR(:,:,t,g))' zeros(n,n);[zeros(n,n*p)]]);
        ACOV(:,:,t,g)=C*inv((eye(8)-C^2))*([PR(:,:,t,g) zeros(n,n);[zeros(n,n*p)]])*(inv((eye(8)-C^2)))';
        c_var11=0;
        c_var21=0;
        c_var31=0;
        c_var41=0;

        c_cov121=0;
        c_cov231=0;
        c_cov341=0;
        c_cov241=0;

        c_cov131=0;
        c_cov141=0;
        c_acov21=0;
        temp5 = zeros(n*p,n*p);
        for i=0:100
            temp = C^i*CH;
            temp1 = C^(i+1)*CH;
            temp11=temp(1,cc);
            temp21=temp(2,cc);
            temp31=temp(3,cc);
            temp41=temp(4,cc);



            temp121=temp11*temp21;
            temp231=temp21*temp31;
            temp341=temp31*temp41;
            temp241=temp21*temp41;

            temp131=temp11*temp31;
            temp141=temp11*temp41;

            c_var11=c_var11+temp11^2;
            c_var21=c_var21+temp21^2;
            c_var31=c_var31+temp31^2;
            c_var41=c_var41+temp41^2;

            c_cov121=c_cov121+temp121;
            c_cov231=c_cov231+temp231;
            c_cov341=c_cov341+temp341;
            c_cov241=c_cov241+temp241;

            c_cov131=c_cov131+temp131;
            c_cov141=c_cov141+temp141;

            temp5 = temp5+C^i*[PR(:,:,t,g) zeros(n,n);[zeros(n,n*p)]]*C^i';

            a2temp1=temp(2,cc)*temp1(2,cc);
            c_acov21 = c_acov21 + a2temp1;


        end
        COV(:,:,t,g) = temp5;
        ACOV(:,:,t,g)=C*COV(:,:,t,g);
        C_VAR11(t,g)=c_var11;
        C_VAR21(t,g)=c_var21;
        C_VAR31(t,g)=c_var31;
        C_VAR41(t,g)=c_var41;


        C_COV121(t,g)=c_cov121;
        C_COV231(t,g)=c_cov231;
        C_COV341(t,g)=c_cov341;
        C_COV241(t,g)=c_cov241;

        C_COV131(t,g)=c_cov131;
        C_COV141(t,g)=c_cov141;
        C_ACOV21(t,g) =c_acov21;
    end
end

C_CORR121=C_COV121./(C_VAR11.^(1/2).*C_VAR21.^(1/2));
C_CORR231=C_COV231./(C_VAR21.^(1/2).*C_VAR31.^(1/2));
C_CORR341=C_COV341./(C_VAR31.^(1/2).*C_VAR41.^(1/2));
C_CORR241=C_COV241./(C_VAR21.^(1/2).*C_VAR41.^(1/2));

C_CORR131=C_COV131./(C_VAR11.^(1/2).*C_VAR31.^(1/2));
C_CORR141=C_COV131./(C_VAR11.^(1/2).*C_VAR41.^(1/2));
AUTOCORR=ACOV./COV;
C_AUTOCORR1 =C_ACOV21./C_VAR21;



eval(['figure(6' num2str(cc) ')'])
subplot(1,2,1)
plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_AUTOCORR1,2),'r-','LineWidth',3); %datetick('x','QQ-YYYY');
yl = ylim;
hold on
for irec=1:length(idx_strt_dates_crisis)
    ybars= zeros(1,2);
    ybars(1)=daten1(idx_strt_dates_crisis(irec));
    ybars(2)=daten1(idx_end_dates_crisis(irec));
patch([ybars(1) ybars(1), ybars(2) ybars(2)],[min(ylim) max(ylim) max(ylim) min(ylim)], [0.8 0.8 0.8])
end
plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_AUTOCORR1,2),'b-','LineWidth',3); %datetick('x','QQ-YYYY');
hold off
ylim(yl)
xlim([datevec_g1(1) datevec_g1(end)])
set(gca,'FontSize',10,'XTick',datevec_g1, 'XTickLabel', datelab_g1); %hold on
title(['Autocorrelation UR conditional on ' tmp_name ' shock'], 'FontSize', 18)

subplot(1,2,2)
plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_CORR231,2),'r-','LineWidth',3); %datetick('x','QQ-YYYY')
hold on
yl = ylim;
%ylim([yl(1)-1, yl(2)+1])
%yl = ylim;
for irec=1:length(idx_strt_dates_crisis)
    ybars= zeros(1,2);
    ybars(1)=daten1(idx_strt_dates_crisis(irec));
    ybars(2)=daten1(idx_end_dates_crisis(irec));
patch([ybars(1) ybars(1), ybars(2) ybars(2)],[min(ylim) max(ylim) max(ylim) min(ylim)], [0.8 0.8 0.8])
end
plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_CORR231,2),'b-','LineWidth',3); %datetick('x','QQ-YYYY')
hold off
ylim(yl)
xlim([datevec_g1(1) datevec_g1(end)])
set(gca,'FontSize',10,'XTick',datevec_g1, 'XTickLabel', datelab_g1);
title(['Correlation UR - CPI conditional on ' tmp_name ' shock'], 'FontSize', 18)

%box(legend,'off')
set(gcf,'Color',[1,1,1])
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);
saveas(figure(61),[name1 'Fig5']);
eval(['print ', '-depsc  ', '  ', [name1 'Fig5'] ]);

eval(['figure(7' num2str(cc) ')'])
subplot(1,3,1)
plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_VAR21.^(1/2),2),'b-','LineWidth',3); %datetick('x','QQ-YYYY','keepticks')
yl = ylim;
hold on
% for irec=1:length(idx_strt_dates_crisis)
%     ybars= zeros(1,2);
%     ybars(1)=daten1(idx_strt_dates_crisis(irec));
%     ybars(2)=daten1(idx_end_dates_crisis(irec));
% patch([ybars(1) ybars(1), ybars(2) ybars(2)],[min(ylim) max(ylim) max(ylim) min(ylim)], [0.8 0.8 0.8])
% end
% plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_VAR21.^(1/2),2),'b-','LineWidth',3); %datetick('x','QQ-YYYY','keepticks')
hold off
ylim(yl)
%xlim([datevec_g1(1) datevec_g1(end)])
xlim([datevec_g2(1)-0.001*datevec_g2(1), datevec_g2(end)+0.001*datevec_g2(end)])
set(gca,'FontSize',8,'XTick',datevec_g2, 'XTickLabel', datelab_g2); 
title(['Standard Deviation UR conditional on ' tmp_name ' shock'], 'FontSize', 12)

subplot(1,3,2)
plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_VAR31.^(1/2),2),'b-','LineWidth',3); %datetick('x','QQ-YYYY','keepticks')
hold on
yl = ylim;
% for irec=1:length(idx_strt_dates_crisis)
%     ybars= zeros(1,2);
%     ybars(1)=daten1(idx_strt_dates_crisis(irec));
%     ybars(2)=daten1(idx_end_dates_crisis(irec));
% patch([ybars(1) ybars(1), ybars(2) ybars(2)],[min(ylim) max(ylim) max(ylim) min(ylim)], [0.8 0.8 0.8])
% end
% plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_VAR31.^(1/2),2),'b-','LineWidth',3); %datetick('x','QQ-YYYY','keepticks')
hold off
ylim(yl)
%xlim([datevec_g1(1) datevec_g1(end)])
xlim([datevec_g2(1)-0.001*datevec_g2(1), datevec_g2(end)+0.001*datevec_g2(end)])
set(gca,'FontSize',8,'XTick',datevec_g2, 'XTickLabel', datelab_g2); 
title(['Standard Deviation CPI conditional on ' tmp_name ' shock'], 'FontSize', 12)


subplot(1,3,3)
plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_COV231,2),'b-','LineWidth',3); %datetick('x','QQ-YYYY','keepticks')
hold on
yl = ylim;
% for irec=1:length(idx_strt_dates_crisis)
%     ybars= zeros(1,2);
%     ybars(1)=daten1(idx_strt_dates_crisis(irec));
%     ybars(2)=daten1(idx_end_dates_crisis(irec));
% patch([ybars(1) ybars(1), ybars(2) ybars(2)],[min(ylim) max(ylim) max(ylim) min(ylim)], [0.8 0.8 0.8])
% end
% plot(daten(end-size(C_CORR231,1)+1:end,1),median(C_COV231,2),'b-','LineWidth',3); %datetick('x','QQ-YYYY','keepticks')
hold off
ylim(yl)
%xlim([datevec_g1(1) datevec_g1(end)])
xlim([datevec_g2(1)-0.001*datevec_g2(1), datevec_g2(end)+0.001*datevec_g2(end)])
set(gca,'FontSize',8,'XTick',datevec_g2, 'XTickLabel', datelab_g2);
title(['Covariance (UR,CPI) conditional on ' tmp_name ' shock'], 'FontSize', 12)

%box(legend,'off')
set(gcf,'Color',[1,1,1])
set(gcf, 'Units', 'Normalized', 'OuterPosition', [0 0 1 1]);
saveas(figure(71),[name1 'Fig6']);
eval(['print ', '-depsc  ', '  ', [name1 'Fig6'] ]);
end




